@@ -1,5 +1,6 @@
 from .accounts.client import _Client as Client
+from .util import Utils
 
 
-__version__ = '5.0.1b'
+__version__ = '5.0.4'
 __author__ = 'Shayan Heidari'
\ No newline at end of file
